Atex.Config
(atex v0.9.1)
Library-wide configuration for Atex.
Configuration
The following keys are supported under config :atex:
config :atex,
plc_directory_url: "https://plc.directory",
service_did: "did:web:my-service.example":plc_directory_url- Base URL for the did:plc directory server. Defaults to"https://plc.directory".:service_did- The DID of this service, used as the expectedaudclaim when validating incoming inter-service auth JWTs viaAtex.XRPC.Router. Required when usingAtex.XRPC.Routerwith auth enabled.
Summary
Functions
Returns the configured base URL for the did:plc directory server.
Returns the configured service DID to be used for validation service auth tokens.
Functions
@spec directory_url() :: String.t()
Returns the configured base URL for the did:plc directory server.
Reads :plc_directory_url from the :atex application environment.
Defaults to "https://plc.directory".
@spec service_did() :: String.t() | nil
Returns the configured service DID to be used for validation service auth tokens.
Reads :service_did from the `:atex application environment.